"""In-process tests for the repo metadata querying functionality"""

import pytest
import os.path
from _fedmod.module_repoquery import ModuleRepoquery

class TestListingModules(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_list_modules(self, capfd):
        self.mr.list_modules()
        out, err = capfd.readouterr()

        assert "reviewboard" in out
        assert "django" in out


class TestListingPackages(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_list_packages(self, capfd):
        self.mr.list_modularized_pkgs()
        out, err = capfd.readouterr()

        assert "ReviewBoard" in out
        assert "python2-django" in out
        assert "(reviewboard)" not in out

    def test_list_packages_with_modules(self, capfd):
        self.mr.list_modularized_pkgs(list_modules=True)
        out, err = capfd.readouterr()

        assert "ReviewBoard" in out
        assert "python2-django" in out
        assert "(reviewboard)" in out


class TestResolvingDependencies(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_list_pkg_deps(self, capfd):
        self.mr.list_pkg_deps(["timeline"], [])
        out, err = capfd.readouterr()

        assert "python2-markdown" in out
        assert "python2-setuptools" in out

    def test_list_pkg_deps_with_module_deps(self, capfd):
        self.mr.list_pkg_deps(["timeline"], ["reviewboard"])
        out, err = capfd.readouterr()

        assert "python2-markdown" not in out
        assert "python2-setuptools" in out


class TestListingPackagesInModule(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_list_rpms_in_module(self, capfd):
        self.mr.list_rpms_in_module("reviewboard")
        out, err = capfd.readouterr()

        assert "ReviewBoard" in out

class TestListingModulesWithPackage(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_list_modules_for_rpm(self, capfd):
        self.mr.list_modules_for_rpm("ReviewBoard")
        out, err = capfd.readouterr()

        assert "reviewboard" in out

class TestGettingSRPMOfRPM(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_get_srpm_for_rpm(self, capfd):
        self.mr.get_srpm_for_rpm("nginx-mimetypes")
        out, err = capfd.readouterr()

        assert "mailcap" in out


class TestGettingRPMSFromSRPM(object):

    def setup(self):
        self.mr = ModuleRepoquery()

    def test_get_rpms_for_rpm(self, capfd):
        self.mr.get_rpms_for_srpm("nginx")
        out, err = capfd.readouterr()

        assert "nginx-all-modules" in out
        assert "nginx-mod-http-perl" in out
